@@ -32,11 +32,11 @@ class SettingsWindow : public QDialog
     Q_OBJECT
 
 public:
-    explicit SettingsWindow(QWidget *parent = 0);
+    explicit SettingsWindow(QWidget *parent = nullptr);
     ~SettingsWindow() override;
 
-private slots:
-    void accept() Q_DECL_OVERRIDE;
+private Q_SLOTS:
+    void accept() override;
     void bgToolButtonClicked();
     void selectSolvedColor();
     void selectUnsolvedColor();
